==> kdevplatform_1.6.0.orig.tar.xz: kdevplatform-1.6.0/plugins/documentview/kdevdocumentview.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=document-preview
Exec=blubb
Comment=This plugin displays a graphical view of all documents currently loaded and separates them by mimetype.
Comment[bs]=Ovaj dodatak prikazuje grafički prikaz svih dokumenata koji su trenutno učitani i razdvaja ih pomoču mimetype-a.
Comment[ca]= Aquest connector mostra una visualització gràfica de tots els documents carregats actualment, separats per tipus MIME.
Comment[ca@valencia]= Este connector mostra una visualització gràfica de tots els documents carregats actualment, separats per tipus MIME.
Comment[da]=Dette plugin viser en grafisk oversigt over alle indlæste dokumenter og adskilder dem efter MIME-type.
Comment[de]=Dieses Modul zeigt alle aktuell geladenen Dokumente getrennt nach ihren MIME-Typen an.
Comment[el]=Το πρόσθετο αυτό εμφανίζει μια γραφική προβολή όλων των εγγράφων που φορτώνονται και τα διαχωρίζει με βάση το αναγνωριστικό τύπου.
Comment[en_GB]=This plugin displays a graphical view of all documents currently loaded and separates them by mimetype.
Comment[es]=Este complemento muestra una vista gráfica de todos los documentos cargados actualmente y los separa por su tipo MIME.
Comment[et]=See plugin näitab graafiliselt kõiki laaditud dokumente ja eraldab need MIME tüübi alusel.
Comment[fi]=Tämä liitännäinen näyttää kaikkien parhaillaan ladattujen asiakirjojen graafisen näkymän ja erottelee ne mime-tyypin perusteella.
Comment[fr]=Ce module externe affiche une vue graphique de tous les documents actuellement chargés et les sépare par type MIME.
Comment[ga]=Taispeánann an breiseán seo amharc grafach ar gach cáipéis atá luchtaithe faoi láthair, agus dealaíonn sé iad de réir a gcineál MIME.
Comment[gl]=Este complemento mostra unha vista gráfica de todos os documentos agora cargados e sepáraos segundo o seu tipo mime.
Comment[hu]=Ez a bővítmény megjeleníti minden jelenleg betöltött dokumentum grafikus nézetét és szétválasztja őket MIME-típus szerint.
Comment[it]=Questa estensione mostra una vista grafica di tutti i documenti attualmente caricati e li separa per il tipo MIME.
Comment[kk]=Бұл плагині бүкіл жүктелген құжаттарды MIME-түрі бойынша бөліп графикалық пішінде көрсетеді.
Comment[nb]=Dette programtillegget gir en grafisk visning av alle dokumenter som nå er lastet inn og skiller dem etter mimetype.
Comment[nds]=Dit Moduul wiest all opstunns laadt Dokmenten graafsch un sorteert se na MIME-Typ.
Comment[nl]=Deze plugin toont een grafische voorstelling van alle nu geladen documenten en scheidt deze door het mimetype.
Comment[pl]=Ta wtyczka udostępnia graficzny widok wszystkich obecnie wczytanych dokumentów i dzieli je według typu MIME.
Comment[pt]=Este 'plugin' mostra uma vista gráfica sobre todos os documentos carregados de momento e separa-os por tipo MIME.
Comment[pt_BR]=Este plugin mostra uma vista gráfica sobre todos os documentos carregados no momento e separa-os por tipo MIME.
Comment[ru]=Это расширение выводит графическое представление всех загруженных в данный момент документов и группирует их по типу MIME.
Comment[sk]=Tento plugin zobrazí grafický pohľad všetkých dokumentov aktuálne načítaných a rozdelí ich podľa mimetype.
Comment[sl]=Ta vstavek prikazuje vse trenutno naložene dokumente in jih ločuje glede na vrsto MIME.
Comment[sv]=Insticksprogrammet visar en grafisk vy av alla dokument som för närvarande har laddats och delar upp dem enligt Mime-typ.
Comment[tr]=Bu eklenti, o anda yüklenmiş olan tüm belgeleri grafiksel bir görünümde gösterir ve o dosyaları mime tiplerine göre ayırır.
Comment[uk]=Цей додаток відображає у графічному вигляді всі відкриті документи і впорядковує їх за типом MIME.
Comment[x-test]=xxThis plugin displays a graphical view of all documents currently loaded and separates them by mimetype.xx
Comment[zh_CN]=此插件显示当前已装入文档的图形视图并按照 mime 类型分类。
Comment[zh_TW]=這個外掛程式顯示目前載入並依 MIME 型態分類的文件的圖形檢視。
Name=Document View
Name[bg]=Изглед за документи
Name[bs]=Pregled Dokumenta
Name[ca]=Visor de document
Name[ca@valencia]=Visor de document
Name[da]=Dokumentvisning
Name[de]=Dokumentansicht
Name[el]=Προβολή εγγράφου
Name[en_GB]=Document View
Name[es]=Vista de documento
Name[et]=Dokumendivaade
Name[fi]=Asiakirjanäkymä
Name[fr]=Vue Document
Name[ga]=Amharc Cáipéise
Name[gl]=Vista do documento
Name[hu]=Dokumentumnézet
Name[it]=Vista documento
Name[ja]=文書ビュー
Name[kk]=Құжат көрінісі
Name[nb]=Dokumentvisning
Name[nds]=Dokmentenansicht
Name[nl]=Document-overzicht
Name[pl]=Widok dokumentu
Name[pt]=Área de Documentos
Name[pt_BR]=Área de Documentos
Name[ru]=Панель документов
Name[sk]=Pohľad na dokumenty
Name[sl]=Prikaz dokumentov
Name[sv]=Dokumentvy
Name[tr]=Belge Görünümü
Name[ug]=پۈتۈك كۆرۈنۈش
Name[uk]=Перегляд документів
Name[x-test]=xxDocument Viewxx
Name[zh_CN]=文档视图
Name[zh_TW]=文件檢視
GenericName=Document Tool
GenericName[bg]=Инструмент за документи
GenericName[bs]=Alat za dokument
GenericName[ca]=Eina de document
GenericName[ca@valencia]=Eina de document
GenericName[da]=Dokumentværktøj
GenericName[de]=Dokument-Werkzeug
GenericName[el]=Εργαλείο εγγράφου
GenericName[en_GB]=Document Tool
GenericName[es]=Herramienta de documento
GenericName[et]=Dokumendi tööriist
GenericName[fi]=Asiakirjatyökalu
GenericName[fr]=Outil Document
GenericName[ga]=Uirlis Cháipéise
GenericName[gl]=Utilidade de documento
GenericName[hu]=Dokumentum eszköz
GenericName[it]=Strumenti documento
GenericName[ja]=文書ツール
GenericName[kk]=Құжат құралы
GenericName[nb]=Dokumentverktøy
GenericName[nds]=Dokmentenwarktüüch
GenericName[nl]=Document-hulpmiddel
GenericName[pl]=Narzędzie dokumentu
GenericName[pt]=Ferramenta de Documentos
GenericName[pt_BR]=Ferramenta de Documentos
GenericName[ru]=Средство просмотра документов
GenericName[sk]=Nástroj na dokumenty
GenericName[sl]=Orodje za dokumente
GenericName[sv]=Dokumentverktyg
GenericName[tr]=Belge Aracı
GenericName[ug]=پۈتۈك قورالى
GenericName[uk]=Інструмент роботи з документами
GenericName[x-test]=xxDocument Toolxx
GenericName[zh_CN]=文档工具
GenericName[zh_TW]=文件工具
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevdocumentview
X-KDE-PluginInfo-Name=kdevdocumentview
X-KDE-PluginInfo-Author=Adam Treat
X-KDE-PluginInfo-Version=0.1
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI

==> kdevplatform-1.6.90.tar.xz: kdevplatform-1.6.90/plugins/documentview/kdevdocumentview.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=document-preview
Exec=blubb
Comment=This plugin displays a graphical view of all documents currently loaded and separates them by mimetype.
Comment[bs]=Ovaj dodatak prikazuje grafički prikaz svih dokumenata koji su trenutno učitani i razdvaja ih pomoču mimetype-a.
Comment[ca]= Aquest connector mostra una visualització gràfica de tots els documents carregats actualment, separats per tipus MIME.
Comment[ca@valencia]= Este connector mostra una visualització gràfica de tots els documents carregats actualment, separats per tipus MIME.
Comment[da]=Dette plugin viser en grafisk oversigt over alle indlæste dokumenter og adskilder dem efter MIME-type.
Comment[de]=Dieses Modul zeigt alle aktuell geladenen Dokumente getrennt nach ihren MIME-Typen an.
Comment[el]=Το πρόσθετο αυτό εμφανίζει μια γραφική προβολή όλων των εγγράφων που φορτώνονται και τα διαχωρίζει με βάση το αναγνωριστικό τύπου.
Comment[en_GB]=This plugin displays a graphical view of all documents currently loaded and separates them by mimetype.
Comment[es]=Este complemento muestra una vista gráfica de todos los documentos cargados actualmente y los separa por su tipo MIME.
Comment[et]=See plugin näitab graafiliselt kõiki laaditud dokumente ja eraldab need MIME tüübi alusel.
Comment[fi]=Tämä liitännäinen näyttää kaikkien parhaillaan ladattujen tiedostojen graafisen näkymän ja erottelee ne MIME-tyypin perusteella.
Comment[fr]=Ce module externe affiche une vue graphique de tous les documents actuellement chargés et les sépare par type MIME.
Comment[ga]=Taispeánann an breiseán seo amharc grafach ar gach cáipéis atá luchtaithe faoi láthair, agus dealaíonn sé iad de réir a gcineál MIME.
Comment[gl]=Este complemento mostra unha vista gráfica de todos os documentos agora cargados e sepáraos segundo o seu tipo mime.
Comment[hu]=Ez a bővítmény megjeleníti minden jelenleg betöltött dokumentum grafikus nézetét és szétválasztja őket MIME-típus szerint.
Comment[it]=Questa estensione mostra una vista grafica di tutti i documenti attualmente caricati e li separa per il tipo MIME.
Comment[kk]=Бұл плагині бүкіл жүктелген құжаттарды MIME-түрі бойынша бөліп графикалық пішінде көрсетеді.
Comment[nb]=Dette programtillegget gir en grafisk visning av alle dokumenter som nå er lastet inn og skiller dem etter mimetype.
Comment[nds]=Dit Moduul wiest all opstunns laadt Dokmenten graafsch un sorteert se na MIME-Typ.
Comment[nl]=Deze plugin toont een grafische voorstelling van alle nu geladen documenten en scheidt deze door het mimetype.
Comment[pl]=Ta wtyczka udostępnia graficzny widok wszystkich obecnie wczytanych dokumentów i dzieli je według typu MIME.
Comment[pt]=Este 'plugin' mostra uma vista gráfica sobre todos os documentos carregados de momento e separa-os por tipo MIME.
Comment[pt_BR]=Este plugin mostra uma vista gráfica sobre todos os documentos carregados no momento e separa-os por tipo MIME.
Comment[ru]=Это расширение выводит графическое представление всех загруженных в данный момент документов и группирует их по типу MIME.
Comment[sk]=Tento plugin zobrazí grafický pohľad všetkých dokumentov aktuálne načítaných a rozdelí ich podľa mimetype.
Comment[sl]=Ta vstavek prikazuje vse trenutno naložene dokumente in jih ločuje glede na vrsto MIME.
Comment[sv]=Insticksprogrammet visar en grafisk vy av alla dokument som för närvarande har laddats och delar upp dem enligt Mime-typ.
Comment[tr]=Bu eklenti, o anda yüklenmiş olan tüm belgeleri grafiksel bir görünümde gösterir ve o dosyaları mime tiplerine göre ayırır.
Comment[uk]=Цей додаток відображає у графічному вигляді всі відкриті документи і впорядковує їх за типом MIME.
Comment[x-test]=xxThis plugin displays a graphical view of all documents currently loaded and separates them by mimetype.xx
Comment[zh_CN]=此插件显示当前已装入文档的图形视图并按照 mime 类型分类。
Comment[zh_TW]=這個外掛程式顯示目前載入並依 MIME 型態分類的文件的圖形檢視。
Name=Document View
Name[bg]=Изглед за документи
Name[bs]=Pregled Dokumenta
Name[ca]=Visor de document
Name[ca@valencia]=Visor de document
Name[da]=Dokumentvisning
Name[de]=Dokumentansicht
Name[el]=Προβολή εγγράφου
Name[en_GB]=Document View
Name[es]=Vista de documento
Name[et]=Dokumendivaade
Name[fi]=Tiedostonäkymä
Name[fr]=Vue Document
Name[ga]=Amharc Cáipéise
Name[gl]=Vista do documento
Name[hu]=Dokumentumnézet
Name[it]=Vista documento
Name[ja]=文書ビュー
Name[kk]=Құжат көрінісі
Name[nb]=Dokumentvisning
Name[nds]=Dokmentenansicht
Name[nl]=Document-overzicht
Name[pl]=Widok dokumentu
Name[pt]=Área de Documentos
Name[pt_BR]=Área de Documentos
Name[ru]=Панель документов
Name[sk]=Pohľad na dokumenty
Name[sl]=Prikaz dokumentov
Name[sv]=Dokumentvy
Name[tr]=Belge Görünümü
Name[ug]=پۈتۈك كۆرۈنۈشى
Name[uk]=Перегляд документів
Name[x-test]=xxDocument Viewxx
Name[zh_CN]=文档视图
Name[zh_TW]=文件檢視
GenericName=Document Tool
GenericName[bg]=Инструмент за документи
GenericName[bs]=Alat za dokument
GenericName[ca]=Eina de document
GenericName[ca@valencia]=Eina de document
GenericName[da]=Dokumentværktøj
GenericName[de]=Dokument-Werkzeug
GenericName[el]=Εργαλείο εγγράφου
GenericName[en_GB]=Document Tool
GenericName[es]=Herramienta de documento
GenericName[et]=Dokumendi tööriist
GenericName[fi]=Tiedostotyökalu
GenericName[fr]=Outil Document
GenericName[ga]=Uirlis Cháipéise
GenericName[gl]=Utilidade de documento
GenericName[hu]=Dokumentum eszköz
GenericName[it]=Strumenti documento
GenericName[ja]=文書ツール
GenericName[kk]=Құжат құралы
GenericName[nb]=Dokumentverktøy
GenericName[nds]=Dokmentenwarktüüch
GenericName[nl]=Document-hulpmiddel
GenericName[pl]=Narzędzie dokumentu
GenericName[pt]=Ferramenta de Documentos
GenericName[pt_BR]=Ferramenta de Documentos
GenericName[ru]=Средство просмотра документов
GenericName[sk]=Nástroj na dokumenty
GenericName[sl]=Orodje za dokumente
GenericName[sv]=Dokumentverktyg
GenericName[tr]=Belge Aracı
GenericName[ug]=پۈتۈك قورالى
GenericName[uk]=Інструмент роботи з документами
GenericName[x-test]=xxDocument Toolxx
GenericName[zh_CN]=文档工具
GenericName[zh_TW]=文件工具
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevdocumentview
X-KDE-PluginInfo-Name=kdevdocumentview
X-KDE-PluginInfo-Author=Adam Treat
X-KDE-PluginInfo-Version=0.1
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI
